

function PD= example_photon_number_detector_prob_distrib(NrPh)


%% Author:  Alvaro Feito, 14 July 2009
%% This file generates a theoretical probability distribution 
%%% for an artificial detector.  It is just an example to 
%%% illustrate how detector_tomography_code.m would work with real data.


 %%% NrPh=25 %%% is the number of photons up to which we expand the POVM %%%





%%% First We create a diagonal POVM (simplest case) 

                %% we invent a POVM which can detect from 0 to 4 clicks
                %% but cannot distinguish "4" from "4 or more" photons



POV_lossy_photon_number_detector=[eye(5,5);zeros(NrPh-5,4),ones(NrPh-5,1)];

%%% Now include loss  (loss matrix L)

K=size(POV_lossy_photon_number_detector)-1;
 eta=.9;  %%% this parameter relates to the loss:
          %%% eta=1 (no loss, perfect detector) 
          %%% eta=0.5 (50/50 Beam splitter in front of the detector)
L=zeros(K(1)+1,K(1)+1);          
 for i=0:K;
     for j=0:i;
         L(j+1,i+1)= nchoosek(i,j)*eta^j*(1-eta)^(i-j);
     end
 end

 
 POV_lossy_photon_number_detector=L'*POV_lossy_photon_number_detector;
 
 
 
 %%%  We Now generate a probability distribution for each event as a
 %%%  function of the probe state. In this case the probe state is |alpha><alpha| 
 %%%  and the probability distribution PD:
 %%%  Pr(alpha, POV) = Tr( |alpha><alpha| POV) for different values of
 %%%  alpha and for the different columns of POV which correspond to
 %%%  different events (like 0 clicks, 1 click, etc)

 
 alpha_cut=250; %% alpha_cut/10 is the cutoff in coherent state amplitude,
                %% alpha_cut is the number of points

 
 

%%% the values of the coherent state amplitudes
coherent_state_amplitudes= [0:alpha_cut-1]./10;

%%% the expansion of the coherent states in the Fock basis                 
matrix_of_coherent_states_in_the_fock_basis=zeros(NrPh,alpha_cut);
                for n=1:(NrPh)
matrix_of_coherent_states_in_the_fock_basis(n,1:alpha_cut)=exp(-coherent_state_amplitudes(1,:)).*coherent_state_amplitudes(1,:).^(n-1)./factorial(n-1);
                end


PD=(matrix_of_coherent_states_in_the_fock_basis'*POV_lossy_photon_number_detector)'  ;  %%%% Generate the Probability Distribution %%
PD(5,:)=ones(1,alpha_cut)-sum(PD(1:4,:));                  %%%%% Normalize the Probability Distribution %%


%%% since our probe state is always measured with some uncertainty, we add
%%% some noise to make this invented data more realistic:

PD=[coherent_state_amplitudes.*(ones(1,alpha_cut)+0.02*rand(1,alpha_cut));PD];


